### Getting the client library

The client library is available on PyPy.

The client depends on other libraries:

- requests
- tenacity

Below is an example of how you can install everything:

    pip install smartobjects requests tenacity

For more information, visit GitHub.

### Create a client instance

The following python code can be used to create an instance:

    key = "<%= clientKey %>"
    secret = "<%= clientSecret %>"
    url = "<%= url %>"
    SmartObjectsClient(key, secret, url)